==> cdktf-cdktf-provider-google-0.6.1.tar.gz: package/lib/data-google-composer-environment.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataGoogleComposerEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
     * Name of the environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/composer_environment#name DataGoogleComposerEnvironment#name}
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * The ID of the project in which the resource belongs.
     *
     * If it is not provided, the provider project is used.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/composer_environment#project DataGoogleComposerEnvironment#project}
     *
     * @stability stable
     */
    readonly project?: string;
    /**
     * The location or Compute Engine region for the environment.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/composer_environment#region DataGoogleComposerEnvironment#region}
     *
     * @stability stable
     */
    readonly region?: string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get clusterIpv4CidrBlock(): string;
    /**
     * @stability stable
     */
    get clusterSecondaryRangeName(): string;
    /**
     * @stability stable
     */
    get servicesIpv4CidrBlock(): string;
    /**
     * @stability stable
     */
    get servicesSecondaryRangeName(): string;
    /**
     * @stability stable
     */
    get useIpAliases(): cdktf.IResolvable;
}
/**
 * @stability stable
 */
export declare class DataGoogleComposerEnvironmentConfigNodeConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get diskSizeGb(): number;
    /**
     * @stability stable
     */
    get ipAllocationPolicy(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get machineType(): string;
    /**
     * @stability stable
     */
    get network(): string;
    /**
     * @stability stable
     */
    get oauthScopes(): string[];
    /**
     * @stability stable
     */
    get serviceAccount(): string;
    /**
     * @stability stable
     */
    get subnetwork(): string;
    /**
     * @stability stable
     */
    get tags(): string[];
    /**
     * @stability stable
     */
    get zone(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComposerEnvironmentConfigPrivateEnvironmentConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get cloudSqlIpv4CidrBlock(): string;
    /**
     * @stability stable
     */
    get enablePrivateEndpoint(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get masterIpv4CidrBlock(): string;
    /**
     * @stability stable
     */
    get webServerIpv4CidrBlock(): string;
}
/**
 * @stability stable
 */
export declare class DataGoogleComposerEnvironmentConfigSoftwareConfig extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get airflowConfigOverrides(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    get envVariables(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    get imageVersion(): string;
    /**
     * @stability stable
     */
    get pypiPackages(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    get pythonVersion(): string;
    /**
     * @stability stable
     */
    get schedulerCount(): number;
}
/**
 * @stability stable
 */
export declare class DataGoogleComposerEnvironmentConfigA extends cdktf.ComplexComputedList {
    /**
     * @stability stable
     */
    get airflowUri(): string;
    /**
     * @stability stable
     */
    get dagGcsPrefix(): string;
    /**
     * @stability stable
     */
    get gkeCluster(): string;
    /**
     * @stability stable
     */
    get nodeConfig(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get nodeCount(): number;
    /**
     * @stability stable
     */
    get privateEnvironmentConfig(): cdktf.IResolvable;
    /**
     * @stability stable
     */
    get softwareConfig(): cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/d/composer_environment google_composer_environment}.
 *
 * @stability stable
 */
export declare class DataGoogleComposerEnvironment extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/d/composer_environment google_composer_environment} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: DataGoogleComposerEnvironmentConfig);
    /**
     * @stability stable
     */
    config(index: string): DataGoogleComposerEnvironmentConfigA;
    /**
     * @stability stable
     */
    get id(): string;
    /**
     * @stability stable
     */
    labels(key: string): string | cdktf.IResolvable;
    private _name?;
    /**
     * @stability stable
     */
    get name(): string;
    /**
     * @stability stable
     */
    set name(value: string);
    /**
     * @stability stable
     */
    get nameInput(): string | undefined;
    private _project?;
    /**
     * @stability stable
     */
    get project(): string;
    /**
     * @stability stable
     */
    set project(value: string);
    /**
     * @stability stable
     */
    resetProject(): void;
    /**
     * @stability stable
     */
    get projectInput(): string | undefined;
    private _region?;
    /**
     * @stability stable
     */
    get region(): string;
    /**
     * @stability stable
     */
    set region(value: string);
    /**
     * @stability stable
     */
    resetRegion(): void;
    /**
     * @stability stable
     */
    get regionInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.6.31.tar.gz: package/lib/data-google-composer-environment.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataGoogleComposerEnvironmentConfig extends cdktf.TerraformMetaArguments {
    /**
    * Name of the environment.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/composer_environment#name DataGoogleComposerEnvironment#name}
    */
    readonly name: string;
    /**
    * The ID of the project in which the resource belongs. If it is not provided, the provider project is used.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/composer_environment#project DataGoogleComposerEnvironment#project}
    */
    readonly project?: string;
    /**
    * The location or Compute Engine region for the environment.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/d/composer_environment#region DataGoogleComposerEnvironment#region}
    */
    readonly region?: string;
}
export declare class DataGoogleComposerEnvironmentConfigNodeConfigIpAllocationPolicy extends cdktf.ComplexComputedList {
    get clusterIpv4CidrBlock(): string;
    get clusterSecondaryRangeName(): string;
    get servicesIpv4CidrBlock(): string;
    get servicesSecondaryRangeName(): string;
    get useIpAliases(): cdktf.IResolvable;
}
export declare class DataGoogleComposerEnvironmentConfigNodeConfig extends cdktf.ComplexComputedList {
    get diskSizeGb(): number;
    get ipAllocationPolicy(): cdktf.IResolvable;
    get machineType(): string;
    get network(): string;
    get oauthScopes(): string[];
    get serviceAccount(): string;
    get subnetwork(): string;
    get tags(): string[];
    get zone(): string;
}
export declare class DataGoogleComposerEnvironmentConfigPrivateEnvironmentConfig extends cdktf.ComplexComputedList {
    get cloudSqlIpv4CidrBlock(): string;
    get enablePrivateEndpoint(): cdktf.IResolvable;
    get masterIpv4CidrBlock(): string;
    get webServerIpv4CidrBlock(): string;
}
export declare class DataGoogleComposerEnvironmentConfigSoftwareConfig extends cdktf.ComplexComputedList {
    get airflowConfigOverrides(): {
        [key: string]: string;
    };
    get envVariables(): {
        [key: string]: string;
    };
    get imageVersion(): string;
    get pypiPackages(): {
        [key: string]: string;
    };
    get pythonVersion(): string;
    get schedulerCount(): number;
}
export declare class DataGoogleComposerEnvironmentConfigA extends cdktf.ComplexComputedList {
    get airflowUri(): string;
    get dagGcsPrefix(): string;
    get gkeCluster(): string;
    get nodeConfig(): cdktf.IResolvable;
    get nodeCount(): number;
    get privateEnvironmentConfig(): cdktf.IResolvable;
    get softwareConfig(): cdktf.IResolvable;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/google/d/composer_environment google_composer_environment}
*/
export declare class DataGoogleComposerEnvironment extends cdktf.TerraformDataSource {
    static readonly tfResourceType: string;
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/google/d/composer_environment google_composer_environment} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataGoogleComposerEnvironmentConfig
    */
    constructor(scope: Construct, id: string, config: DataGoogleComposerEnvironmentConfig);
    config(index: string): DataGoogleComposerEnvironmentConfigA;
    get id(): string;
    labels(key: string): string | cdktf.IResolvable;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _project?;
    get project(): string;
    set project(value: string);
    resetProject(): void;
    get projectInput(): string | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
